@@ -161,3 +161,8 @@ void KKAGroup::addPrintData( QPtrList<KKAContactData>& data )
 		}
 	}
 }
+
+void KKAGroup::addImportData( KKAContactData* data )
+{
+	m_list.append( data );
+}
