@@ -22,6 +22,8 @@
 #include "kkaperson.h"
 #include "kkacontactdata.h"
 
+#include <qdragobject.h>
+
 #include <klocale.h>
 #include <kdebug.h>
 #include <kmainwindow.h>
@@ -39,6 +41,7 @@ KKAListView::KKAListView( QWidget* parent, const char* name )
 	setRootIsDecorated( true );
 	setAllColumnsShowFocus( true );
 	setDefaultRenameAction( Accept );
+	setDragEnabled( true );
 
 	KAction* act;
 
@@ -97,3 +100,14 @@ void KKAListView::personRemove()
 	delete currentItem();
 	delete data;
 }
+
+void KKAListView::startDrag()
+{
+	KKAPerson* item = (KKAPerson*)currentItem();
+	if( !item ) return;
+	QStoredDrag *d = new QStoredDrag( "application/x-kreetingkard_person", this );
+	QCString cstr;
+	cstr.setNum( (long)item );
+	d->setEncodedData( cstr );
+	d->dragMove();
+}
