@@ -19,6 +19,7 @@
  ***************************************************************************/
 #include "kkatreeview.h"
 #include "kkagroup.h"
+#include "kkaperson.h"
 
 #include <kglobal.h>
 #include <qfile.h>
@@ -39,10 +40,10 @@ KKATreeView::KKATreeView( QWidget* parent, const char* name )
 	setFullWidth( true );
 	setRootIsDecorated( true );
 	setDefaultRenameAction( Accept );
-// 	setDragEnabled( true );
-// 	setDropVisualizer( true );
-// 	setItemsMovable( false );
-// 	setAcceptDrops( true );
+	setAcceptDrops( true );
+	setDragEnabled( true );
+	setDropVisualizer( true );
+	setItemsMovable( false );
 
 	readData();
 
@@ -185,3 +186,26 @@ QPtrList<KKAContactData> KKATreeView::printData()
 	}
 	return data;
 }
+
+void KKATreeView::contentsDragEnterEvent( QDragEnterEvent* event )
+{
+	event->accept( event->format( 0 ) == "application/x-kreetingkard_person" );
+}
+
+void KKATreeView::contentsDragMoveEvent( QDragMoveEvent* event )
+{
+}
+
+void KKATreeView::contentsDropEvent( QDropEvent* event )
+{
+	QListViewItem* item = itemAt( event->pos() );
+	if( !item ) return;
+	if( QString( event->format( 0 ) ) == "application/x-kreetingkard_person" )
+	{
+		QCString cstr( event->encodedData( "application/x-kreetingkard_person" ) );
+		KKAPerson* person = (KKAPerson*)cstr.toLong();
+		((QListView*)event->source())->takeItem( person );
+		KKAGroup* group = (KKAGroup*)item;
+		group->addImportData( person->data() );
+	}
+}
