@@ -24,6 +24,7 @@
 #include "kkadetailview.h"
 #include "kkagroup.h"
 #include "kkaperson.h"
+#include "kkacontactxml.h"
 
 #include "../kkdesigner/kkddoc.h"
 #include "../kkdesigner/kkdview.h"
@@ -46,12 +47,15 @@ using namespace KKAddressBook;
 KKAWidget::KKAWidget( KKDesigner::KKDDoc* doc, KCommandHistory* cmdHistory, QWidget* parent, const char* name )
 	: KKWidgetBase( cmdHistory, parent, name )
 {
+	m_data = NULL;
+	
+	m_doc = doc;
 	m_tvwGroup = new KKATreeView( this );
 	m_spl = new QSplitter( Qt::Vertical, this );
 	m_lvwPerson = new KKAListView( m_spl );
-	QSplitter* hbox = new QSplitter( m_spl );
-	m_dvwPerson = new KKADetailView( hbox );
-	m_preview = new KKDesigner::KKDView( KKDesigner::KKDItemBase::AddressMode, doc, hbox );
+	m_hbox = new QSplitter( m_spl );
+	m_dvwPerson = new KKADetailView( m_hbox );
+	m_preview = NULL;
 	if( m_tvwGroup->currentItem() )
 	{
 		m_lvwPerson->groupChanged( m_tvwGroup->currentItem() );
@@ -63,6 +67,16 @@ KKAWidget::KKAWidget( KKDesigner::KKDDoc* doc, KCommandHistory* cmdHistory, QWid
 	}
 	connect( m_tvwGroup, SIGNAL( currentChanged( QListViewItem* ) ), this, SLOT( groupChanged( QListViewItem* ) ) );
 	groupChanged( m_tvwGroup->currentItem() );
+	
+	KActionMenu* actm = new KActionMenu( i18n( "&Import" ), "fileimport", actionCollection(), "import" );
+	KAction* act = new KAction( i18n( "&ContactXML..." ), "contactxml", KShortcut(), this, SLOT( importContactXML() ), actionCollection() );
+	actm->insert( act );
+
+/*	actm = new KActionMenu( i18n( "&Export" ), "fileexport", actionCollection(), "export" );
+	act = new KAction( i18n( "&ContactXML..." ), "contactxml", KShortcut(), this, SLOT( exportContactXML() ), actionCollection() );
+	actm->insert( act );*/
+
+	new KToggleAction( i18n( "&Preview" ), "", KShortcut(), this, SLOT( togglePreview() ), actionCollection(), "preview" );
 }
 
 KKAWidget::~KKAWidget()
@@ -83,6 +97,12 @@ void KKAWidget::readConfig( KConfig* conf )
 	{
 		m_spl->setSizes( conf->readIntListEntry( "VSplit" ) );
 	}
+	
+	if( conf->readBoolEntry( "Preview" ) )
+	{
+		((KToggleAction*)action( "preview" ))->setChecked( true );
+		togglePreview();
+	}
 }
 
 void KKAWidget::saveConfig( KConfig* conf )
@@ -90,6 +110,7 @@ void KKAWidget::saveConfig( KConfig* conf )
 	conf->setGroup("AddressBook");
 	conf->writeEntry( "HSplit", sizes() );
 	conf->writeEntry( "VSplit", m_spl->sizes() );
+	conf->writeEntry( "Preview", ((KToggleAction*)action( "preview" ))->isChecked() );
 }
 
 bool KKAWidget::closable()
@@ -124,7 +145,11 @@ void KKAWidget::groupChanged( QListViewItem* g )
 
 void KKAWidget::setContactData( QListViewItem* d )
 {
-	m_preview->setContactData( d ? ((KKAPerson*)d)->data() : NULL );
+	if( m_preview )
+	{
+		m_preview->setContactData( d ? ((KKAPerson*)d)->data() : NULL );
+	}
+	m_data = d;
 }
 
 QPtrList<KKAContactData> KKAWidget::printData()
@@ -136,3 +161,31 @@ QPtrList<KKAContactData> KKAWidget::printData()
 	}
 	return m_tvwGroup->printData();
 }
+
+void KKAWidget::importContactXML()
+{
+	KKAContactXML::doImport( m_tvwGroup );
+}
+
+void KKAWidget::exportContactXML()
+{
+	KKAContactXML::doExport( m_tvwGroup );
+}
+
+void KKAWidget::togglePreview()
+{
+	if( ((KToggleAction*)action( "preview" ))->isChecked() )
+	{
+		if( !m_preview )
+		{
+			m_preview = new KKDesigner::KKDView( KKDesigner::KKDItemBase::AddressMode, m_doc, m_hbox );
+			m_preview->documentChanged();
+			setContactData( m_data );
+		}
+		m_preview->show();
+	}
+	else
+	{
+		m_preview->hide();
+	}
+}
