@@ -39,7 +39,6 @@
 #include "kkdaddressee.h"
 #include "kkdaddress.h"
 #include "kkdzipcode.h"
-#include "kkditemdialog.h"
 #include "kkdinputtextdialog.h"
 
 #include "../kkaddressbook/kkacontactdata.h"
@@ -388,6 +387,9 @@ void KKDCanvas::mousePressEvent( QMouseEvent* e )
 						menu->insertSeparator();
 					}
 					action( "locked" )->plug( menu );
+					menu->insertSeparator();
+					action( "edit_select_all" )->plug( menu );
+					action( "edit_deselect" )->plug( menu );
 					menu->exec( e->globalPos() );
 					break;
 				}
