@@ -112,8 +112,8 @@ void KKDCmdBase::setName( const QString &name )
 KKDCmdOrientation::KKDCmdOrientation( KKDDoc* doc )
 	: KKDCmdBase( doc )
 {
-	connect( this, SIGNAL( executed() ), doc, SIGNAL( datafieldChanged() ) );
-	connect( this, SIGNAL( unexecuted() ), doc, SIGNAL( datafieldChanged() ) );
+	connect( this, SIGNAL( executed() ), doc, SIGNAL( orientationChanged() ) );
+	connect( this, SIGNAL( unexecuted() ), doc, SIGNAL( orientationChanged() ) );
 }
 
 void KKDCmdOrientation::execute( KKDItemBase* item )
