@@ -55,20 +55,21 @@ KKDDoc::~ KKDDoc()
 {
 }
 
-void KKDDoc::open( const QString& filename )
+bool KKDDoc::open( const QString& filename )
 {
 	QFile file( filename );
 	if( !file.open( IO_ReadOnly ) )
 	{
 		KMessageBox::error( (QWidget*)parent(), i18n( "File open error\n%1" ).arg( filename ) );
-		return;
+		return false;
 	}
 
 	QDomDocument doc( "kreetingkard" );
 	if( !doc.setContent( &file ) )
 	{
 		KMessageBox::error( (QWidget*)parent(), i18n( "File is not kreetingkard format" ) );
-		return;
+		file.close();
+		return false;
 	}
 	file.close();
 
@@ -91,6 +92,7 @@ void KKDDoc::open( const QString& filename )
 		}
 	}
 	emit documentChanged();
+	return true;
 }
 
 bool KKDDoc::save( const QString& filename )
@@ -196,13 +198,19 @@ void KKDDoc::selectAll()
 {
 	KKDPaper* paper = at( currentIndex() );
 	setSelected( paper, false, true, false );
-	for( KKDItemBase* item = first(); item; item = next() )
+	QPtrList<KKDItemBase> list( *paper );
+	for( KKDItemBase* item = list.first(); item; item = list.next() )
 	{
 		setSelected( item, true, false, false );
 	}
 	emit selectedChanged();
 }
 
+void KKDDoc::deselect()
+{
+	setSelected( current(), true, true, true );
+}
+
 /**
  * @english
  * Select item(s) included @p rect.
@@ -906,6 +914,7 @@ void KKDDoc::eraseImage()
 //BEGIN ImagePrint
 bool KKDDoc::imagePrint()
 {
+	if( !current() ) return false;
 	return current()->imagePrint();
 }
 
