@@ -72,7 +72,7 @@ namespace KKDesigner
 
 		bool readOnly(){ return m_cmdHistory == NULL; }
 
-		void open( const QString& filename );
+		bool open( const QString& filename );
 		bool save( const QString& filename );
 		void close();
 		void print( QPainter& p, KKAddressBook::KKAContactData* d = 0 );
@@ -119,6 +119,7 @@ namespace KKDesigner
 
 		void selectRect( const QRect& rect, bool clearAll = true );
 		void selectAll();
+		void deselect();
 		//END Actions
 
 		//BEGIN Properties
