@@ -41,10 +41,11 @@
 #include <kmessagebox.h>
 #include <kiconloader.h>
 #include <kfontdialog.h>
-#include <tkcoloractions.h>
+// #include <tkcoloractions.h>
 #include <kprinter.h>
 #include <kmainwindow.h>
 #include <kxmlguiclient.h>
+#include <kcolordialog.h>
 
 using namespace KKDesigner;
 
@@ -139,8 +140,9 @@ KKDWidget::KKDWidget( KCommandHistory* cmdHistory, QWidget* parent, const char*
 
 	new KToggleAction( i18n( "StrikeOut" ), "text_strike", KShortcut(Qt::CTRL + Qt::Key_Minus), this, SLOT( setFontStrikeOut() ), actionCollection(), "fontstrikeout" );
 
-	TKSelectColorAction* actC = new TKSelectColorAction( i18n( "Color..." ), TKSelectColorAction::TextColor, this, SLOT( setColor() ), actionCollection(), "color", true );
-	actC->setDefaultColor( QColor() );
+	new KAction( i18n( "Color..." ), "kcoloredit", KShortcut(), this, SLOT( setColor() ), actionCollection(), "color" );
+/*	TKSelectColorAction* actC = new TKSelectColorAction( i18n( "Color..." ), TKSelectColorAction::TextColor, this, SLOT( setColor() ), actionCollection(), "color", true );
+	actC->setDefaultColor( QColor() );*/
 	//END Font related
 
 	new KToggleAction( i18n( "Lock" ), "encrypted", KShortcut(Qt::CTRL + Qt::Key_L), this, SLOT( setLocked() ), actionCollection(), "locked" );
@@ -156,12 +158,13 @@ KKDWidget::KKDWidget( KCommandHistory* cmdHistory, QWidget* parent, const char*
 	new KAction( i18n( "&Font Installer" ), "kcmfontinst", 0, this, SLOT( fontinst() ), actionCollection(), "fontinst" );
 
 	KStdAction::selectAll( m_doc, SLOT( selectAll() ), actionCollection() );
+	KStdAction::deselect( m_doc, SLOT( deselect() ), actionCollection() );
 	KStdAction::cut( m_doc, SLOT( cut() ), actionCollection() );
 	KStdAction::copy( m_doc, SLOT( copy() ), actionCollection() );
 	KStdAction::paste( m_doc, SLOT( paste() ), actionCollection() );
 
 
-	KStdAction::preferences( this, SLOT( preferences() ), actionCollection() );
+// 	KStdAction::preferences( this, SLOT( preferences() ), actionCollection() );
 	setEditActionEnabled();
 
 
@@ -243,10 +246,12 @@ void KKDWidget::fileOpen( const QString& filename, bool blCheckChanged )
 	}
 
 	QApplication::setOverrideCursor( KCursor::waitCursor() );
-	m_doc->open( filename );
-	QApplication::restoreOverrideCursor();
+	if( m_doc->open( filename ) )
+	{
+		m_filename = filename;
+	}
+	commandHistory()->clear();
 
-	m_filename = filename;
 	setEditActionEnabled();
 
 	resetCaption();
@@ -262,6 +267,7 @@ void KKDWidget::fileOpen( const QString& filename, bool blCheckChanged )
 	setActionColor();
 	setActionImagePrint();
 	setActionImageErase();
+	QApplication::restoreOverrideCursor();
 }
 
 void KKDWidget::openRecent( const KURL& url )
@@ -539,8 +545,13 @@ void KKDWidget::setAlign()
 
 void KKDWidget::setColor()
 {
-	m_doc->setColor( ((TKSelectColorAction*)action( "color" ))->color() );
-	setActionColor();
+	QColor color( m_doc->color() );
+	if( KColorDialog::getColor( color, this ) == KColorDialog::Accepted )
+	{
+// 		m_doc->setColor( ((TKSelectColorAction*)action( "color" ))->color() );
+		m_doc->setColor( color );
+		setActionColor();
+	}
 }
 
 void KKDWidget::setImagePrint()
@@ -651,7 +662,7 @@ void KKDWidget::setActionAlign()
 
 void KKDWidget::setActionColor()
 {
-	((TKSelectColorAction*)action( "color" ))->setCurrentColor( m_doc->color() );
+// 	((TKSelectColorAction*)action( "color" ))->setCurrentColor( m_doc->color() );
 }
 
 void KKDWidget::setActionImagePrint()
@@ -782,6 +793,10 @@ void KKDWidget::setEditActionEnabled()
 	setActionEnabled( "insertzipcode", enabled );
 	setActionEnabled( "remove", enabled );
 	setActionEnabled( "edit_select_all", enabled );
+	setActionEnabled( "edit_deselect", enabled );
+
+	setActionEnabled( "horizontal", enabled );
+	setActionEnabled( "vertical", enabled );
 
 	setActionEnabled( "alignleft", enabled );
 	setActionEnabled( "aligncenter", enabled );
@@ -807,6 +822,6 @@ void KKDWidget::setEditActionEnabled()
 	setActionEnabled( "edit_cut", enabled && ( m_doc->cutable() ) );
 	setActionEnabled( "edit_copy", enabled && ( m_doc->copyable() ) );
 	setActionEnabled( "edit_paste", enabled && m_doc->pastable() );
-	setActionEnabled( "view_zoom_in", enabled );
-	setActionEnabled( "view_zoom_out", false );
+/*	setActionEnabled( "view_zoom_in", enabled );
+	setActionEnabled( "view_zoom_out", false );*/
 }
