@@ -30,7 +30,7 @@
 static const char description[] =
 	I18N_NOOP("A Greeting Card Editor for KDE");
 
-static const char version[] = "0.6.1";
+static const char version[] = "0.6.2";
 
 static KCmdLineOptions options[] =
 {
@@ -41,9 +41,10 @@ static KCmdLineOptions options[] =
 int main(int argc, char **argv)
 {
 	KAboutData about( "kreetingkard", I18N_NOOP("KreetingKard"), version, description,
-				KAboutData::License_GPL, I18N_NOOP("(C) 2004-, KreetingKard developers"), 0, "http://linux-life.net/program/cc/kde/app/kreetingkard/", "tasuku@linux-life.net");
+					  KAboutData::License_GPL, I18N_NOOP("(C) 2004-, KreetingKard developers"), 0, "http://linux-life.net/program/cc/kde/app/kreetingkard/", "kreetingkard-devel@lists.sourceforge.jp");
 	about.addAuthor( I18N_NOOP("Tasuku Suzuki"), I18N_NOOP("Author"), "tasuku@linux-life.net", "http://linux-life.net/" );
-	about.addAuthor( I18N_NOOP("Kazuki Ohta"), I18N_NOOP("Developer"), "mover@hct.zaq.ne.jp", "http://mover.cool.ne.jp/" );
+	about.addCredit( I18N_NOOP( "UTUMI Hirosi" ), I18N_NOOP( "Bug report" ), "utuhiro78@yahoo.co.jp", "http://www.geocities.jp/ep3797/" );
+	about.addCredit( I18N_NOOP("Kazuki Ohta"), I18N_NOOP("Developer"), "mover@hct.zaq.ne.jp", "http://mover.cool.ne.jp/" );
 	KCmdLineArgs::init(argc, argv, &about);
 	KCmdLineArgs::addCmdLineOptions( options );
 	KKApplication::addCmdLineOptions();
